| clanc.intcv | R Documentation |
Build a Classification to Nearest Centroids classifier on the objective data.
clanc.intcv(kfold = 5, X, y, seed)
kfold |
number of folds. By default, |
X |
dataset to be trained. This dataset must have rows as probes and columns as samples. |
y |
a vector of sample group of each sample for the dataset to be trained.
It must have an equal length to the number of samples in |
seed |
an integer used to initialize a pseudorandom number generator. |
a list of 4 elements:
mc |
an internal misclassification error rate |
time |
the processing time of performing internal validation with ClaNC |
model |
a ClaNC classifier, resulted from |
Alan R. Dabney, Author Notes.(2005) ClaNC: point-and-click software for classifying microarrays to nearest centroids, https://academic.oup.com/bioinformatics/article/22/1/122/219377
set.seed(101)
biological.effect <- estimate.biological.effect(uhdata = uhdata.pl)
ctrl.genes <- unique(rownames(uhdata.pl))[grep("NC", unique(rownames(uhdata.pl)))]
biological.effect.nc <- biological.effect[!rownames(biological.effect)
%in% ctrl.genes, ]
group.id <- substr(colnames(biological.effect.nc), 7, 7)
biological.effect.train.ind <- colnames(biological.effect.nc)[c(sample(which(
group.id == "E"), size = 64),
sample(which(group.id == "V"), size = 64))]
biological.effect.nc.tr <- biological.effect.nc[, biological.effect.train.ind]
clanc.int <- clanc.intcv(X = biological.effect.nc.tr,
y = substr(colnames(biological.effect.nc.tr), 7, 7),
kfold = 5, seed = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.