| create.storage | R Documentation |
During the implement of precision.simulate function, according to the length of design.list,
class.list, and norm.list, to create a storage list to store the output from precision.simulate.
create.storage(
design.list = c("CC+", "CC-", "PC+", "PC-"),
class.list = c("PAM", "LASSO"),
norm.list = c("NN", "QN"),
validating.sets = c("test", "gold.standard")
)
design.list |
List of design methods to be applied in |
class.list |
List of classification methods to be applied in |
norm.list |
List of normalization methods to be applied in |
validating.sets |
Types of validation methods. |
create.storage
A list whose size is determined by the input parameters.
create.storage(design.list = c("CC+", "CC-", "PC+", "PC-"),
class.list = c("PAM", "LASSO"),
norm.list = c("NN", "QN"),
validating.sets = c("test", "gold.standard"))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.