| switch.classifier.funcs.class | R Documentation |
Transform classfication method names into a fitting function name and a prediction function name, for using in the classfication procedure
switch.classifier.funcs.class(
class.list = c("PAM", "LASSO", "ClaNC", "ranFor", "SVM", "kNN", "DLDA", "custom"),
class.funcs = NULL,
pred.funcs = NULL
)
class.list |
A list of classification method name to be transformed. The build-in methods are "PAM", "LASSO", "ClaNC", "ranFor", "SVM", "kNN" and "DLDA". |
class.funcs |
Other classfication functions that users can create by themselves. |
pred.funcs |
Other prediction funcstions that users can create by themselves. |
switch.classifier.funcs.class
A list containing build.funcs, which means the fitting function names, and pred.funcs,
which means the prediction function names. The fitting functions is to be fitted on the training set and prediction
function is to be used on the test set.
switch.classifier.funcs.class(class.list = c("PAM", "LASSO", "ClaNC", "ranFor", "SVM"), class.funcs = NULL, pred.funcs = NULL)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.